unit fjUtil;

interface

uses
    Windows, SysUtils, Classes, DateUtils;

function DateText(const AFrom, ATo: TDateTime): string; overload;
function DateText(const Dt: TDateTime): string; overload;
function SizeText(const ByteSize: integer): string;
procedure Tail(const Path: string; Lines: TStrings; const Count: integer);
function FileSizeByFileSize(const FileName: string): Int64;
function FileModifiedByGetFileTime(const FileName: string): TDateTime;

implementation

//  ---------------------------------------------------------------------------
//  oߕ\
function DateText(const AFrom, ATo: TDateTime): string;
var
    Sec, MillSec: Int64;
begin
    MillSec := MilliSecondsBetween(AFrom, ATo);
    Sec := SecondsBetween(AFrom, ATo);

    if (Sec > 10) then
        Result := FormatFloat('#,##0 sec', Sec)
    else
        Result := FormatFloat('#,##0 msec', MillSec)
    ;
end;

//  ---------------------------------------------------------------------------
//  t\
function DateText(const Dt: TDateTime): string;
begin
    Result := FormatDateTime('c', Dt);
end;

//  ---------------------------------------------------------------------------
//  oCgTCY\
function SizeText(const ByteSize: integer): string;
var
    MegaByte, KiloByte: double;
begin
    KiloByte := ByteSize / 1024;
    MegaByte := KiloByte / 1024;

    if (MegaByte > 10) then
        Result := FormatFloat('#,##0 MB', MegaByte)
    else if (KiloByte > 10) then
        Result := FormatFloat('#,##0 KB', KiloByte)
    else
        Result := FormatFloat('#,##0 B', ByteSize)
    ;
end;

//  ---------------------------------------------------------------------------
//  Ns\
procedure Tail(const Path: string; Lines: TStrings; const Count: integer);
var
    FS: TFileStream;
    SL: TStringList;
    i, First, Final: integer;
begin
    try
        FS := TFileStream.Create(Path, fmOpenRead or fmShareDenyNone);
        try
            SL := TStringList.Create;
            try
                SL.BeginUpdate();
                SL.LoadFromStream(FS);
                Final := SL.Count - 1;
                if (Count = -1) then First := 0 else First := Final - Count + 1;
                if (First < 0) then First := 0;
                Lines.BeginUpdate();
                Lines.Clear();
                for i := First to Final do
                begin
                    Lines.Add(SL.Strings[i]);
                end;
                Lines.EndUpdate();
                SL.EndUpdate();
            finally
                SL.Free;
            end;
        finally
            FS.Free;
        end;
    except
        ;
    end;
end;

//  ---------------------------------------------------------------------------
//  t@CTCY擾(FileSize)
function FileSizeByFileSize(const FileName: string): Int64;
var
    F: file;                            //  ^Ȃt@C
begin
    Result := -1;
    try
        AssignFile(F, FileName);
        try
            Reset(F, 1);                //  oCgt@C
            Result := FileSize(F);
        finally
            CloseFile(F);
        end;
    except
    end;
end;

//  ---------------------------------------------------------------------------
//  ŏIXV擾(GetFileTime)
//  http://hp.vector.co.jp/authors/VA009712/take/delphi/kabesys.htm#datetimefile2
function FileModifiedByGetFileTime(const FileName: string): TDateTime;
var
    FileHandle: integer;
    ftCreateDate: TFileTime;
    ftModifyDate: TFileTime;
    ftAccessDate: TFileTime;
    lftModifyDate: TFileTime;
    stModifyDate: TSystemTime;
begin
    Result := 0;
    try
        FileHandle := FileOpen(FileName, fmOpenRead or fmShareDenyNone);
        if (FileHandle >= 0) then
        begin
            try
                //  t@C̓擾
                GetFileTime(FileHandle, @ftCreateDate, @ftAccessDate, @ftModifyDate);
                //  [JɕύX
                FileTimeToLocalFileTime(ftModifyDate, lftModifyDate);
                //  VXeɕύX
                FileTimeToSystemTime(lftModifyDate, stModifyDate);
                Result := SystemTimeToDateTime(stModifyDate);
            finally
                FileClose(FileHandle);
            end;
        end;
    except
    end;
end;

end.

